@@ -28,6 +28,7 @@ var NAVTREE =
     [ "SoapDataProvider Module", "index.html", [
       [ "Introduction to the SoapDataProvider Module", "index.html#soapdataproviderintro", null ],
       [ "Release Notes", "index.html#soapdataprovider_relnotes", [
+        [ "SoapDataProvider v1.1", "index.html#soapdataprovider_v1_1", null ],
         [ "SoapDataProvider v1.0", "index.html#soapdataprovider_v1_0", null ]
       ] ]
     ] ],
@@ -37,6 +38,7 @@ var NAVTREE =
     [ "Classes", "annotated.html", [
       [ "Class List", "annotated.html", "annotated_dup" ],
       [ "Class Index", "classes.html", null ],
+      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
       [ "Class Members", "functions.html", [
         [ "All", "functions.html", null ],
         [ "Functions", "functions_func.html", null ],
